@@ -8,9 +8,8 @@ import shutil
 from pyramid.config import Configurator
 from pyramid.httpexceptions import HTTPFound
 from pyramid.httpexceptions import HTTPNotFound
-from pyramid.session import UnencryptedCookieSessionFactoryConfig
+from pyramid.session import SignedCookieSessionFactory
 from pyramid.view import view_config
-from wsgiref.simple_server import make_server
 
 try:
     import sqlalchemy
@@ -39,13 +38,26 @@ here = os.path.dirname(os.path.abspath(__file__))
 
 @view_config(route_name='test_exc')
 def exc(request):
-    raise NotImplementedError
+    raise RuntimeError
+
+@view_config(route_name='test_squashed_exc')
+def squashed_exc(request):
+    raise RuntimeError
+
+@view_config(
+    route_name='test_squashed_exc',
+    context=RuntimeError,
+    renderer='notfound.mako',
+)
+def squashed_exc_error_view(request):
+    request.response.status_code = 404
+    return {}
 
 @view_config(route_name='test_notfound')
 def notfound(request):
     raise HTTPNotFound()
 
-@view_config(route_name='test_ajax', renderer='__main__:templates/ajax.mako')
+@view_config(route_name='test_ajax', renderer='ajax.mako')
 def test_ajax(request):
     return {}
 
@@ -53,12 +65,12 @@ def test_ajax(request):
 def call_ajax(request):
     return {'ajax':'success'}
 
-@view_config(context=HTTPNotFound, renderer='__main__:templates/notfound.mako')
+@view_config(context=HTTPNotFound, renderer='notfound.mako')
 def notfound_view(request):
     request.response.status_code = 404
     return {}
 
-@view_config(renderer='__main__:templates/index.mako') # found via traversal
+@view_config(renderer='index.mako')  # found via traversal
 def test_page(request):
     title = 'Pyramid Debugtoolbar'
     log.info(title)
@@ -72,21 +84,19 @@ def test_redirect(request):
     return HTTPFound(location='/')
 
 @view_config(route_name='test_highorder',
-             renderer='__main__:templates/highorder.mako')
+             renderer='highorder.mako')
 def test_highorder(request):
     return {}
 
 @view_config(route_name='test_predicates',
-             renderer='__main__:templates/index.mako')
+             renderer='index.mako')
 def test_predicates(request):
     return {'title': 'Test route predicates'}
 
 @view_config(route_name='test_chameleon_exc',
-             renderer='__main__:templates/error.pt')
-@view_config(route_name='test_mako_exc',
-             renderer='__main__:templates/error.mako')
-@view_config(route_name='test_jinja2_exc',
-             renderer='__main__:templates/error.jinja2')
+             renderer=__name__ + ':templates/error.pt')
+@view_config(route_name='test_mako_exc', renderer='error.mako')
+@view_config(route_name='test_jinja2_exc', renderer='error.jinja2')
 def test_template_exc(request):
     return {'title': 'Test template exceptions'}
 
@@ -96,7 +106,7 @@ class DummyRootFactory(object):
     def __getitem__(self, name):
         return self
 
-if __name__ == '__main__':
+def make_app():
     # configuration settings
     try:
         # ease testing py2 and py3 in same directory
@@ -104,17 +114,21 @@ if __name__ == '__main__':
     except:
         pass
     settings = {}
-    settings['reload_templates'] = True
-    settings['mako.directories'] = '__main__:templates'
-    settings['mako.module_directory'] = '__main__:mako_modules'
+    settings['pyramid.reload_templates'] = True
+    settings['jinja2.directories'] = __name__ + ':templates'
+    settings['mako.directories'] = __name__ + ':templates'
+    settings['mako.module_directory'] = __name__ + ':mako_modules'
     settings['debugtoolbar.reload_templates'] = True
     settings['debugtoolbar.hosts'] = ['127.0.0.1']
     settings['debugtoolbar.intercept_redirects'] = True
+    settings['debugtoolbar.exclude_prefixes'] = ['/static', '/favicon.ico']
+
     # session factory
-    session_factory = UnencryptedCookieSessionFactoryConfig('itsaseekreet')
+    session_factory = SignedCookieSessionFactory('itsaseekreet')
     # configuration setup
-    config = Configurator(settings=settings, session_factory=session_factory,
-                          root_factory=DummyRootFactory)
+    config = Configurator(settings=settings)
+    config.set_session_factory(session_factory)
+    config.set_root_factory(DummyRootFactory)
     # static view
     config.add_static_view('static', os.path.join(here, 'static'))
     # routes setup
@@ -127,8 +141,9 @@ if __name__ == '__main__':
     config.add_route('test_jinja2_exc', '/jinja2_exc')
     config.add_route('test_highorder', text_(b'/La Pe\xc3\xb1a', 'utf-8'))
     config.add_route('test_ajax', '/ajax')
+    config.add_route('test_squashed_exc', '/squashed_exc')
     config.add_route('call_ajax', '/call_ajax')
-    config.scan('__main__')
+    config.scan(__name__)
     config.include('pyramid_chameleon')
     config.include('pyramid_jinja2')
     config.include('pyramid_mako')
@@ -136,6 +151,11 @@ if __name__ == '__main__':
     if sqlalchemy:
         config.include('sqla')
     config.include('pyramid_debugtoolbar')
-    app = config.make_wsgi_app()
+    return config.make_wsgi_app()
+
+app = make_app()
+
+if __name__ == '__main__':
+    from wsgiref.simple_server import make_server
     httpd = make_server('', 8080, app)
     httpd.serve_forever()
