@@ -17,28 +17,10 @@
 # make it absolute, like shown here.
 #sys.path.append(os.path.abspath('some/directory'))
 
-import sys, os
-
+import datetime
 import pkg_resources
-
-# Add and use Pylons theme
-if 'sphinx-build' in ' '.join(sys.argv):  # protect against dumb importers
-    from subprocess import call, Popen, PIPE
-    cwd = os.getcwd()
-    p = Popen('which git', shell=True, stdout=PIPE)
-    here = os.path.abspath(os.path.dirname(__file__))
-    parent = os.path.abspath(os.path.dirname(here))
-    _themes = os.path.join(here, '_themes')
-    git = p.stdout.read().strip()
-    try:
-        os.chdir(parent)
-        if not os.listdir(_themes):
-            call([git, 'submodule', 'update', '--init', '--recursive'])
-        else:
-            call([git, 'submodule', 'update'])
-        sys.path.append(_themes)
-    finally:
-        os.chdir(cwd)
+import pylons_sphinx_themes
+import sys, os
 
 # General configuration
 # ---------------------
@@ -53,7 +35,7 @@ extensions = [
 # Looks for pyramid's objects
 intersphinx_mapping = {
     'pyramid':
-    ('http://docs.pylonsproject.org/projects/pyramid/en/latest/', None)}
+    ('https://docs.pylonsproject.org/projects/pyramid/en/latest/', None)}
 
 # Add any paths that contain templates here, relative to this directory.
 templates_path = ['.templates']
@@ -66,7 +48,8 @@ master_doc = 'index'
 
 # General substitutions.
 project = 'pyramid_debugtoolbar'
-copyright = '2012, Agendaless Consulting <chrism@plope.com>'
+thisyear = datetime.datetime.now().year
+copyright = '2012-%s, Agendaless Consulting' % thisyear
 
 # The default replacements for |version| and |release|, also used in various
 # other places throughout the built documents.
@@ -114,10 +97,13 @@ pygments_style = 'sphinx'
 # -----------------------
 
 # Add and use Pylons theme
-sys.path.append(os.path.abspath('_themes'))
-html_theme_path = ['_themes']
+html_theme_path = pylons_sphinx_themes.get_html_themes_path()
 html_theme = 'pyramid'
-html_theme_options = dict(github_url='https://github.com/Pylons/pyramid_debugtoolbar')
+html_theme_options = {
+    'github_url': 'https://github.com/Pylons/pyramid_debugtoolbar',
+    'canonical_url':
+        'https://docs.pylonsproject.org/projects/pyramid_debugtoolbar/en/latest',
+}
 
 # The style sheet to use for HTML and HTML Help pages. A file of that name
 # must exist either in Sphinx' static/ path, or in one of the custom paths
@@ -151,12 +137,18 @@ html_theme_options = dict(github_url='https://github.com/Pylons/pyramid_debugtoo
 # bottom, using the given strftime format.
 html_last_updated_fmt = '%b %d, %Y'
 
-# If true, SmartyPants will be used to convert quotes and dashes to
-# typographically correct entities.
-#html_use_smartypants = True
+# Do not use smart quotes.
+smartquotes = False
 
 # Custom sidebar templates, maps document names to template names.
-#html_sidebars = {}
+# Control display of sidebars
+html_sidebars = { '**': [
+    'localtoc.html',
+    'ethicalads.html',
+    'relations.html',
+    'sourcelink.html',
+    'searchbox.html',
+] }
 
 # Additional templates that should be rendered to pages, maps page names to
 # template names.
@@ -201,12 +193,12 @@ htmlhelp_basename = 'atemplatedoc'
 #  author, document class [howto/manual]).
 latex_documents = [
   ('index', 'pyramid_debugtoolbar.tex', 'pyramid_debugtoolbar Documentation',
-   'Repoze Developers', 'manual'),
+   'Pylons Project Developers', 'manual'),
 ]
 
 # The name of an image file (relative to this directory) to place at the
 # top of the title page.
-latex_logo = '.static/logo_hi.gif'
+# latex_logo = '.static/logo_hi.gif'
 
 # For "manual" documents, if this is true, then toplevel headings are
 # parts, not chapters.
